---
layout: post
title: The Relevance of Social Science
categories:
 - political science
tags:
 - political science
 - engagement
 - communication
 - teaching
---

Over the last two years, political scientists of all stripes have engaged - with one another, members of Congress, and journalists - about the *relevance* of the discipline. I've largely stayed out of the debate, especially during the period last year when [the Coburn Amendment](http://www.apsanet.org/content_85560.cfm) limited the funding of political science by the U.S. National Science Foundation. But now I think it's time to put my two cents out there.

The question of relevance is an important one. If a discipline is irrelevant, it will eventually cease to exist - there will be no demand for its research, for its experts, or for its students. When the relevance of a discipline is questioned, it is unsurprising that those embedded within it will try to defend their work and that of their peers. And political scientists have been quick to defend the relevance of the discipline on a number of fronts, most prominently in terms of how interesting, normatively important, and perhaps influential political science research should be. 

Reactions to outside criticism seem to have come largely in the form of [a defensive response that adopts the dominant frame imposed by the critics](http://themonkeycage.org/2012/05/10/what-nsf-funded-projects-have-taught-us-about-national-security-issues/). Namely, when told that political science is not an economically valuable discipline, political scientists have responded on those same terms, arguing that the particular research projects funded (e.g., [by the NSF](http://themonkeycage.org/2012/05/15/what-has-the-nsf-wrought/)) constitute economically and politically valuable expenditures. This response, I believe, is flawed. And the willingness of political scientists to adopt the imposed frame of reference reflects both (1) a failure to act according to the findings of our own research, and (2) a somewhat narrow definition of relevance. I address both of these in turn.

[E.E. Schattschneider](http://en.wikipedia.org/wiki/Elmer_Eric_Schattschneider) once wrote that "Every fight consists of two parts: (1) the few individuals who are actively engaged at the center and (2) the audience that is irresistibly attracted to the scene." When political science research - indeed all scientific research - is politicized by journalists and politicians, we (the scientists) and the critics are at the center. But Schattschneider also reminds us that "If a fight starts, watch the crowd, because the crowd plays the decisive role." His point is that one cannot win a fight by defeating the opponent, but instead by drawing the audience to their side. When political scientists argue to critics - be it Tom Coburn, Nicholas Kristof, or anyone else - we waste our energies in a fruitless battle.

To construct a slightly different metaphor, think of the KKK. Social scientific research shows that this hate group is among America's least liked groups and has held that status for decades. Yet other social scientific research shows that the KKK and similar hate groups continue to be tolerated by society despite their racist, hateful, and violent tendencies because their activities appeal to higher-order social values that are broadly held: namely, the widespread support for unrestricted freedom of speech. An abundance of experimental research shows that when hate groups are threatened with restrictions on their activities (e.g., to hold public rallies deemed potentially violent), the most effective response is for them to appeal to free speech values rather than argue that their activities are non-violent. Reframing the debate, not responding, is what protects the group, even though it is widely disliked.

When scientific research is criticized for lacking public value or for being insufficiently relevant to policy or society, we simply cannot resort to adopting our critic's frame of reference. Instead, we need to reframe the debate. Doing so requires rethinking and expanding the definition of relevance and changing the way we draw the audience into the fight over scientific funding.

To bolster their attacks, [social science critics often point to examples of NSF-funded research that are, on face value, bizarre](http://en.wikipedia.org/wiki/National_Science_Foundation:_Under_the_Microscope). Projects about ranking soccer players, analyzing Congressional websites, or studying the impact of FarmVille seem strange. But this is precisely because they constitute basic research. And these are precisely the types of research that NSF was created to support. Similarly bizarre examples can be found in the archives of research supported by NSF Directorates other than Social, Behavioral, and Economic Sciences. Basic research is interesting precisely because it is odd: its precise implications are unknown, it ventures beyond the state-of-the-art, and it takes risks that might prevent profit-minded firms from supporting it.

When we defend these specific projects we implicitly adopt the critic's frame of reference - that the work of science is about single studies producing plainly visible policy implications - without shifting the debate. A better response points out not the value of specific projects but the value of the enterprise. It is irrelevant whether a soccer player rating system helps society in any direct way. What matters is whether subsequent research was able to build from that contribution to expand our knowledge and create social or economic value. The value of science is not in any specific article, knowledge, algorithm, or technique; the value of science is from its collective contribution. Funding specific projects injects resources and energy that stimulate that diffuse, collective activity in a competitive fashion.

If scientific value derives from accumulated contributions, this also means that the critics often ask scientists (political or otherwise) to do precisely what they should not do. [With calls for greater use of social media and scientific articles written in prose intended for mass consumption](http://www.nytimes.com/2014/02/16/opinion/sunday/kristof-professors-we-need-you.html?smid=tw-share&_r=1), the critics demand a disservice to both science and the public. To the former, a scientific literature written without technical language is a literature that is imprecise and difficult to advance. Scientific writing needs to be technical; making it otherwise [would damage the ability of scientists to do their work](http://mischiefsoffaction.blogspot.dk/2014/02/what-academic-wants-what-kristof-needs.html). To the latter, rapidly disseminated summaries of particular studies can mislead policymakers and the public. Individual studies - for a whole host of statistical and practical reasons - rarely reveal the precise effects of anything. Scientific knowledge comes from the progressive accumulation of evidence about patterns and relationships.

One need only look to health journalism to see the consistent abuse of single-study findings to misguide the public about the value of particular foods, medications, and behaviors. I do not want policymakers or the public reading individual scientific studies, especially those that have not yet been peer-reviewed. They need to be reading about the results of systematic reviews, like those distributed by [the Cochrane Collaboration](http://www.cochrane.org/). The findings there have huge policy relevance even if none of individual studies underlying those reviews alone merits much public consideration.

But getting journalists and policymakers to understand the collective, cumulative, and progressive nature of science and the value of public investment therein ultimately requires a focus on a form of relevance that I've seen far too little discussion of. The most significant impact that scientists have on society comes in the form of undergraduate education. Our relevance hinges not on how many of us use Twitter or how many of our studies can be cited in Congressional testimony or *The New York Times*, but instead on the training and preparation of a scientifically literate public.

If students, regardless of university or major, understand the enterprise of science (including social science), understand the value that it collectively brings to society, and learn how to apply systematically generated scientific knowledge in their work and in their private lives, then they are better off. If some of those people go on to become policymakers and bureaucrats who understand and know how to apply collective scientific knowledge to the enactment and implementation of sound policies, then we are all better off. Over half of the American public has some college education. Our students - past and present - are the audience in the fight over the public value of science. If the audience knows that (social) science is valuable, then we've already won the battle.

