---
layout: post
title: A Comment on Open Science
categories:
 - political science
tags:
 - political science
 - open science
 - open access
 - publishing
 - conferences
---

Open science is important. Making knowledge and the data underlying that knowledge freely and widely available is a fundamental part of the enterprise of science. Unfortunately, science is typically not open. Instead, most research is hidden behind paywalls (all of my published empirical research is) and most data are never made public ([but all of mine is public](http://thedata.harvard.edu/dvn/dv/leeper)).

It is therefore really exciting when there are opportunities to share scientific research in an open way. But seemingly open science is often actually closed science.

In the past year, I've seen a lot of blog posts (e.g., on [The Monkey Cage](http://www.washingtonpost.com/blogs/monkey-cage/)) describing new research with a note that the publisher has agreed to make the article freely available *for a limited time* (examples [here](http://www.washingtonpost.com/blogs/monkey-cage/wp/2014/04/25/humanitarian-appeals-encourage-a-permissive-immigration-policy/), [here](http://www.washingtonpost.com/blogs/monkey-cage/wp/2013/10/18/dangerous-neighborhoods-why-the-democratic-peace-may-have-more-to-do-with-geography-than-democracy/), or [here](http://www.washingtonpost.com/blogs/monkey-cage/wp/2014/01/30/what-makes-some-elections-violent/)). These articles are no longer freely available (despite the clear value in sharing that research), because the authors who created the scientific discoveries gave away their ownership (i.e., copyright) to the publishers, who control access to knowledge.

Here's another example, again highlighting The Monkey Cage. John Sides' and Lynn Vavreck's 2012 election book *The Gamble* [was advertised as having open-access chapters available online](http://themonkeycage.org/2013/01/24/new-e-chapter-of-the-gamble-available-its-free/) even though they would eventually publish the book with Princeton University Press. Those chapters are no longer available online now that the book is published in print.

These examples serve to highlight that there is a lot of good science being produced (here, I focus on science in my own discipline of political science) and all stakeholders - researchers, publishers, journalists, and public - see value in having that research freely available. Yet one of these stakeholders, publishers, goes against the interests of all seemingly because they are the only ones who have the opportunity to profit from the research.

I think this is a huge problem. The work of science is done by researchers, either with their own funding and resources, resources provided by universities (and thus, ultimately paid for by undergraduate tuition fees), or through direct or indirect public financing. Publishers have no financial stake in the production of scientific research. And yet they alone have the opportunity to profit from it, with those profits coming almost exclusively from the very universities that fund the research in the first place. [As recent controversy surrounding Elsevier reveals](http://www.theguardian.com/science/2014/jun/16/universities-get-poor-value-academic-journal-publishing-firms), the prices universities actually pay for closed access are also highly arbitrary.

## Doing some things differently ##

I think science (and the world) would be better off if this was different.

I'd like to see all scientific articles published in open access journals with all accompanying data in persistent open data repositories. I hope most other scientists would agree in principle. Yet there's a lot of skepticism among academics about this. Open access journals are conflated with predatory journals that are "pay for publication" outlets. There's also a huge amount of value placed (e.g., during tenure review) on the particular outlets where research is published. In political science, the *American Political Science Review* and *American Journal of Political Science* are widely seen as the top scholarly outlets. Despite being owned by the American Political Science Association and the Midwest Political Science Association, respectively, which are member-funded, non-profit organizations, the journals themselves operate as profit-generating products for publishers rather than as open access outlets.

If a researcher wants to operate within existing incentive structures (i.e., tenure structures), she must aim for the "top" journals, a goal that necessarily conflicts with the higher ideal of open science. This should change. Maybe outlets like [Research & Politics](http://www.uk.sagepub.com/researchandpolitics/) will change things for the better for open science, but I'm skeptical until the major journals (like APSR and AJPS) are converted to open access.

One of the other major strands of skepticism about open science relates to financing. Critics of open access sometimes higlight that journals cost money to operate. But most of the true costs are paid for free (authors, editors, and reviewers typically work with minimal or no compensation). The operating costs (review process management, typesetting, printing, and online access) are marginal. Open source journals like [*The R Journal*](http://journal.r-project.org/) and [the *Journal of Statistical Software*](http://www.jstatsoft.org/) are entirely open acess, peer-reviewed, and operated with minimal overhead. When I [recently published](http://journal.r-project.org/archive/accepted/leeper.pdf) in *The R Journal*, I typeset my own manuscript in LaTeX. The servers to host the journals are paid for through academic sponsorship and foundation support.

Open science is what we make it and we can make it nearly for free. Indeed, we're already subsidizing closed science with our labor as authors, reviewers, and editors.

## So what does this all mean? ##

The only thing that stands in the way of open science is publishers (and ultimately ourselves). The only reason we keep using publishers to publish research seems to be because we've done so in the past (also, they pay for food and booze at conference receptions). All of our science could be open access if we wanted it to be. We could then divert library resources currently used to fund journal subscriptions to pay for operating and hosting open access journals and institutional archives for working papers and data. (Of course, that's a bit unrealistic in the short-term because publishers own copyrights on a huge pool of 20th and 21st century scientific output that we'll have to continue to pay subscription fees to access for the next few decades.) 

In short, scientists control the production of science, so we should control our own access and the public's access to our work. This requires changing our incentive structures for what is a good outlet for research, changing the structure of scientific outlets we do control (like association-owned journals), and changing the way we think about science as an enterprise. There's a lot of money in scientific publishing and that money should go to fund scientific research, not to publishers.

So this leads to my last point, which is actually the thing that prompted me to write this post at all. Open science sounds good, but it is also easily coopted. The [predatory "open access" journals](http://scholarlyoa.com/publishers/) are one good example.

But there are also more subtle forms of this - organizations that operate in more of a gray area between closed science and open science. One of them is ubiquitous in the lives of social scientists and it is called the [Social Science Research Network](http://www.ssrn.com/en/). The American Political Science Association makes a concerted effort to get Annual Meeting presenters to share their conference papers on the SSRN archive. This sounds good. SSRN states that it is committed to open access and it hosts a huge amount of research in the form of conference and working papers. But SSRN is a for-profit, privately held corporation. It does not disclose its ownership structure, its revenue, or its expenditures. The software that runs the archive is closed source. The company admits, at least in concept, to paying dividends to its owners. I don't see this kind of entity as compatible with open science. In practical terms, this means I won't be putting my APSA conference paper on SSRN. It's unfortunate that our discipline has no alternative outlet.

If we want to have open science, we need to have truly open science that includes open, peer-reviewed grant-making, reproducible scientific processes, open-access peer-reviewed publishing outlets, and permanent, unrestricted access to all scientific output. For-profit entities and academic publishers may play some valuable role in that process, but that role is non-obvious to me. I would like to see science controlled by scientists and non-profit organizations that are committed to reinvesting revenue toward furthering open science.
