---
layout: post
title: "One Simple Step Toward Improving Academic Hiring and Recruitment"
description: "Academic hiring processes often encourage illegal and unethical questioning during interviews. Here's one thing that might change interviews for the better."
tags:
 - higher education
 - academia
 - job market
 - hiring
---

Academic hiring is weird. It involves people hiring their future coworkers. It is also mostly conducted by people (i.e., academics) with no expertise or training in human resources and scant direct knowledge of laws regulating hiring. One way this manifests is in the all-too-often asked "illegal questions." These questions involve topics that are irrelevant to a hiring decision, things like sexual orientation, family life, caring responsibilities, and so forth. In some countries and at some universities, there are specifically enumerated topics that are off-topic and are illegal to ask during an interview. In other places, there is only a professional obligation to follow ethics and norms about keeping conversations during interviews on-topic (namely on the actual job of being an academic).

Unfortunately, people engaged in academic hiring ask illegal questions. It happens. All. The. Time. Why? Probably two reasons: (1) lack of training and knowledge of relevant laws and regulations, and (2) the blurred line between vetting job candidates and recruiting job candidates. (Of course there are other reasons, but I'll stick to these two.) Hiring departments often have to serve a dual function of deciding whom to hire, while also having conversations with potential hires about why they should accept an offer (if one is made). A question that might be relevant to recruitment - for example, "Do you have children?" - might be asked in order to advertise particularly attractive local, national, or university childcare policies that are broadly relevant to job candidates. But the specific ask is clearly an illegal question, even if well-motivated. Worse, it might not be well-motivated at all, and - if we believe what we hear from fellow academics - is probably going to be disproprtionately asked of female scholars.

So what can we do? I ask because this relates to an issue our department has been discussing - namely, what can we do to best balance our dual functions of vetting candidates and advertising our department, university, and city. (One answer is education. I'm just going to set that aside without discussing it.) Instead, I want to encourage departments to think about how to tease apart the dual functions of hiring and recruitment and, when we recognize that these functions are inherently incompatible, develop separate procedures for conducting each.

The starting place might be to acknowledge and formalize the separation of the two functions. To draw a *screen* (or ["Chinese Wall"](https://en.wikipedia.org/wiki/Chinese_wall) in archaic but perhaps more precise or familiar terms) between department faculty handling hiring and recruitment. Indeed, those engaged in each task should not be in contact with one another during the hiring process. One group - the hiring committee and those empowered to decide on a hire (this varies by institution) - should be solely focused on vetting candidates. Another group (likely smaller and possibly composed of individuals with a more distant stake in the hire) should be tasked with recruitment.

Many places already practice this informally. In "American"-style interviews, a job talk and series of "one-on-ones" are typically treated as methods of vetting a candidate. A dinner with select faculty is seen as a more informal opportunity to engage in recruitment such as advertising the nice restaurants in town and talking about social life in the area. In "British"-style interviews, there might be a research presentation, panel interview, and teaching demonstration that are treated as vetting activities, and meet-and-greet lunch is treated as informal recruitment and socializing. (Of course, regardless of any apparent informality, candidates should assume they are always "on".) Yet this arrangement becomes problematic if conversations about recruitment (that possibly touch on partnerships, children, etc.) are fed back into hiring decisions. A formal screen between those responsible for hiring and recruitment, whereby the content of recruitment activities is kept isolated from decision makers is the only way to prevent recruitment-related topics from (consciously or unconsciously) influencing hiring decisions.

Then, with this formal separation in place, I think it's a good idea for departments to enumerate an extensive list of topics that should be addressed during the recruitment portion of an interview. This might cover a wide array of topics: salaries, promotion expectations, access to research money, housing expenses and cost of living, childcare, health coverage, spousal considerations, and so forth. A portion of recruitment time should then be spent to clarify the formal screen, identify point people on each side of the screen (hiring committee chair or head of department on the one; recruitment lead on the other), explicitly say to candidates "We have identified a set of topics that job candidates may find useful to know and we communicate them to everyone," and then basically walk through that list.

Formalizing the set of topics to be discussed ensures that all candidates are provided with the same information, thus avoiding gender, racial, age, or other biases in the discussion of sensitive topics. Formalizing the screen further ensures that those topics can be discussed as needed, but only at the initiative of the candidate. There are some lingering ethical issues (e.g., who is appointed to what roles, given that a recruitment role necessarily sacrifices voting rights? are there any topics that would need to cross the screen for other legal reasons?), but I think this formalization may be useful to both departments and the candidates they interview.
